# -*- coding:utf-8 -*-
__title__ = 'cgai_time'
__version__ = '0.0.9'
__author__ = 'Master Zhang'
__author_email__ = '360014296@qq.com'
__license__ = 'GPLv3'
__description__ = """cgai_time {}
一个日期时间计算工具

open for any contributions, issue reporting. even if you have any idea about this package you are warmly accepted!
just check out: https://github.com/zxzxde/cgai-time
""".format(__version__)